==> apache-geode-benchmarks-1.13.8-src.tgz: apache-geode-benchmarks-1.13.8-src/geode-benchmarks/src/main/java/org/apache/geode/benchmark/parameters/ProfilerParameters.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license
 * agreements. See the NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The ASF licenses this file to You under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */

package org.apache.geode.benchmark.parameters;

import static com.google.common.base.Strings.isNullOrEmpty;
import static org.apache.geode.benchmark.parameters.Utils.configureAll;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import org.apache.geode.perftest.TestConfig;

public class ProfilerParameters {
  private static final Logger logger = LoggerFactory.getLogger(ProfilerParameters.class);

  public static void configure(final TestConfig testConfig) {
    final String profilerArgument = System.getProperty("benchmark.profiler.argument");
    if (!isNullOrEmpty(profilerArgument)) {
      logger.info("Configuring profiler parameter. {}", profilerArgument);
      configureAll(testConfig, profilerArgument);
    }
  }

}

==> apache-geode-benchmarks-1.15.2-src.tgz: apache-geode-benchmarks-1.15.2-src/geode-benchmarks/src/main/java/org/apache/geode/benchmark/parameters/ProfilerParameters.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license
 * agreements. See the NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The ASF licenses this file to You under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */

package org.apache.geode.benchmark.parameters;

import static com.google.common.base.Strings.isNullOrEmpty;
import static org.apache.geode.benchmark.parameters.Utils.configureGeodeProductJvms;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import org.apache.geode.perftest.TestConfig;

public class ProfilerParameters {
  private static final Logger logger = LoggerFactory.getLogger(ProfilerParameters.class);

  public static void configure(final TestConfig testConfig) {
    final String profilerArgument = System.getProperty("benchmark.profiler.argument");
    if (!isNullOrEmpty(profilerArgument)) {
      logger.info("Configuring profiler parameter. {}", profilerArgument);
      configureGeodeProductJvms(testConfig, profilerArgument);
    }
  }

}
